**** Online Appendix C
**** Foldincrease_covar_adjust.do
**** Cheung et al. (2017) Multivariable regression analysis of fold-increase endpoints using a distributional approach for paired antibody data
**** Stata codes for case study of influenza serological response in relation to overweight with adjustment for age
   
clear
set more off
 
version 13.1

*** Specify folder name
* cd C:\Projects\NovelStat\Foldincrease\Covariate\CHIP

*** Specify data file name
* use CHIP01_25Jan2016.dta,clear

* keep if overweight!=. & age!=. & t!=. & (titre0!=. | titre1!=.)  
 
*** Data format: two rows per person
*** titre0 and titre1 are log(2) transformed standard antibody titers

*** Example data rows obtained by: list id t titre0 titre1 overweight age in 1/6,clean noobs
*** id   t   titre0   titre1   overwe~t    age  
*** 11   0        0        .          0   38.7  
*** 11   1        .        0          0   38.7  
*** 12   0        1        .          1   41.2  
*** 12   1        .        1          1   41.2  
*** 13   0        1        .          1   42.1  
*** 13   1        .        1          1   42.1  

*** Doulbing dilution from 1:10 to 1:640; on log(2) scale from 1 to 7
*** Each log-transformed titer Y is censored within the interval [LY, UY]
gen titre=cond(titre0!=.,titre0,titre1)
gen LY=cond(titre==0,.,titre)
gen UY=cond(titre==7,.,titre+1)

*** Fit linear mixed effects model, based on expression (8) 
xtset id
xtintreg LY UY  t##(overweight c.age), i(id) 

*** Get risk parameters using the Stata command predictnl, based on expression (9)
*** logC=2 indicates 4-fold increase
*** logb=3 indicates antibody>=40 at end-of-study

preserve
keep if t==0

local logC=2
local logb=3

*** Estimator for the risk parameter in overweight group(adjusted) and its 95%CI 
predictnl risk1=normal(([LY]_b[1.t]+[LY]_b[1.t#1.overweight]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2)) ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#1.overweight]+[LY]_b[1.t#c.age]*age-`logC')/[sigma_e]_b[_cons]/sqrt(2), ///
				(`logb'-[LY]_b[_cons]-[LY]_b[1.overweight]-[LY]_b[age]*age -[LY]_b[1.t]-[LY]_b[1.t#1.overweight]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2), ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)),se(serisk1)
summarize risk1 
local r1 = r(mean)
summarize serisk1 
local se1 = r(mean)
local r1_ub = `r1' + 1.96*`se1'
local r1_lb = `r1'- 1.96*`se1'

*** Estimator for the risk parameter in non-overweight group(adjusted) and its 95%CI  
predictnl risk0=normal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2)) ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age-`logC')/[sigma_e]_b[_cons]/sqrt(2), ///
				(`logb'-[LY]_b[_cons]-[LY]_b[age]*age -[LY]_b[1.t]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2), ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)),se(serisk0)
summarize risk0 
local r0 = r(mean) 
summarize serisk0
local se0 = r(mean)
local r0_ub = `r0' + 1.96*`se0'
local r0_lb = `r0'- 1.96*`se0'
 
*** Estimator for log of risk ratio RR_ATE(adjusted) based on expression(11) and its 95%CI  
predictnl logrr=ln( 1/[_N] * sum( (normal(([LY]_b[1.t]+[LY]_b[1.t#1.overweight]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2))   ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age+[LY]_b[1.t#1.overweight]-`logC')/[sigma_e]_b[_cons]/sqrt(2), ///
				(`logb'-[LY]_b[_cons]-[LY]_b[1.overweight]-[LY]_b[age]*age -[LY]_b[1.t]-[LY]_b[1.t#1.overweight]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2), ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)) ) / (normal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2))  ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2),  ///
				(`logb'-[LY]_b[_cons]-[LY]_b[age]*age-[LY]_b[1.t]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2),   ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)) )) ), se(logrr_se)
	
local rr_ATE = exp(logrr[_N])
local se_ATE = logrr_se[_N]
local rr_ATE_ub = exp(logrr[_N] + 1.96*`se_ATE')
local rr_ATE_lb = exp(logrr[_N] - 1.96*`se_ATE') 
 
*** Estimator for log of risk ratio RR_PTE(adjusted) based on expression(12) and its 95%CI
predictnl lnrr=ln(sum(normal(([LY]_b[1.t]+[LY]_b[1.t#1.overweight]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2)) ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#1.overweight]+[LY]_b[1.t#c.age]*age-`logC')/[sigma_e]_b[_cons]/sqrt(2), ///
				(`logb'-[LY]_b[_cons]-[LY]_b[1.overweight]-[LY]_b[age]*age -[LY]_b[1.t]-[LY]_b[1.t#1.overweight]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2), ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)))/sum(normal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2)) ///
				-binormal(([LY]_b[1.t]+[LY]_b[1.t#c.age]*age -`logC')/[sigma_e]_b[_cons]/sqrt(2), ///
				(`logb'-[LY]_b[_cons]-[LY]_b[age]*age-[LY]_b[1.t]-[LY]_b[1.t#c.age]*age)/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2), ///
				-[sigma_e]_b[_cons]/sqrt([sigma_e]_b[_cons]^2+[sigma_u]_b[_cons]^2)/sqrt(2)))), se(lnrr_se)

local rr_PTE =  exp(lnrr[_N])
local se_PTE = lnrr_se[_N]
local rr_PTE_ub = exp(lnrr[_N] + 1.96*`se_PTE')
local rr_PTE_lb = exp(lnrr[_N] - 1.96*`se_PTE')

restore 

*** Tabulate estimates and their 95%CIs
mat a=(`r1', `r1_lb', `r1_ub')\(`r0', `r0_lb', `r0_ub')\(`rr_PTE', `rr_PTE_lb', `rr_PTE_ub')\(`rr_ATE', `rr_ATE_lb', `rr_ATE_ub')
mat rownames a=r1 r0 RR_PTE RR_ATE 
mat colnames a=Estimate lb_95%CI ub_95%CI
disp "Fold-increase analysis, Adjust for age"
matlist a 

 
